@@ -40,7 +40,7 @@ TemplatizerWindow* TemplatizerWindow::create()
 
 TemplatizerWindow::TemplatizerWindow(BaseObjectType* baseObject, 
                              const Glib::RefPtr<Gtk::Builder>& xml)
- : Gtk::Window(baseObject)
+ : Gtk::Window(baseObject), name_column("Templates", name_renderer)
 {
   nag_on_delete = true;
   signal_size_allocate().connect(sigc::mem_fun(*this, &TemplatizerWindow::on_window_allocated));
@@ -50,7 +50,9 @@ TemplatizerWindow::TemplatizerWindow(BaseObjectType* baseObject,
   xml->get_widget("scrolledwindow", scrolled_window);
   set_icon_from_file(Main::get_data_path() + "/templatizer.png");
   xml->get_widget("treeview", treeview);
-  treeview->append_column("Templates", templates_columns.name);
+  name_column.set_cell_data_func
+    (name_renderer, sigc::mem_fun(*this, &TemplatizerWindow::cell_data_name));
+  treeview->append_column(name_column);
   templates_list = Gtk::ListStore::create(templates_columns);
   sorted_templates_list = Gtk::TreeModelSort::create(templates_list);
   sorted_templates_list->set_sort_column(templates_columns.name, Gtk::SORT_ASCENDING);
@@ -107,10 +109,10 @@ TemplatizerWindow::TemplatizerWindow(BaseObjectType* baseObject,
   text_buffer = Gsv::Buffer::create();
   text_buffer->signal_changed().connect(sigc::mem_fun(*this, &TemplatizerWindow::on_textview_changed));
   textview = new Gsv::View(text_buffer);
-  textview->set_wrap_mode(Gtk::WRAP_WORD);
   textview->signal_focus_out_event().connect(sigc::mem_fun(*this, &TemplatizerWindow::on_leaving_textview));
   scrolled_window->add(*manage(textview));
   scrolled_window->show_all();
+  textview->set_wrap_mode(Gtk::WRAP_WORD);
     
   context_actions = Gtk::ActionGroup::create();
   context_actions->add(Gtk::Action::create("ContextNew", "New Template ..."),
@@ -224,6 +226,14 @@ void TemplatizerWindow::on_new_clicked()
       sorted_templates_list->set_sort_column(templates_columns.name, Gtk::SORT_ASCENDING);
       treeview->set_model(sorted_templates_list);
       update_buttons();
+      //here we go about selecting the new template
+      for (Gtk::TreeIter i = sorted_templates_list->children().begin(),
+           end = sorted_templates_list->children().end(); i != end; ++i) 
+        if ((*i)[templates_columns.template_data] == t)
+          {
+            treeview->get_selection()->select(i);
+            break;
+          }
     }
 }
 
@@ -402,7 +412,10 @@ void TemplatizerWindow::on_search_icon_clicked(Gtk::EntryIconPosition pos, const
       for (Gtk::TreeIter i = sorted_templates_list->children().begin(),
            end = sorted_templates_list->children().end(); i != end; ++i) 
         if ((*i)[templates_columns.template_data] == t)
-          treeview->get_selection()->select(i);
+          {
+            treeview->get_selection()->select(i);
+            break;
+          }
     }
 }
 
@@ -517,3 +530,10 @@ void TemplatizerWindow::on_window_allocated(Gtk::Allocation & allocation)
 {
   update_buttons();
 }
+
+void TemplatizerWindow::cell_data_name(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i)
+{
+  Gtk::CellRendererText*cell = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  cell->property_ellipsize() = Pango::ELLIPSIZE_END;
+  cell->property_text() =  (*i)[templates_columns.name];
+}
